This function creates the results data model in the specified schema within
the results database. The results data model is used to hold the study
results and must be created before using [@seealso uploadResults()]
Usage
createResultDataModel(
analysisSpecifications,
resultsDataModelSettings,
resultsConnectionDetails
)Arguments
- analysisSpecifications
An object of type
AnalysisSpecificationsas created bycreateEmptyAnalysisSpecificiations().- resultsDataModelSettings
The results data model settings as created using [@seealso
createResultsDataModelSettings()]- resultsConnectionDetails
The connection details to the results database which is an object of class
connectionDetailsas created by theDatabaseConnector::createConnectionDetails()function.